==> ejc-sealm-api-3.0.0-20220107.080017-19-sources.jar: com.ejianc.business.sealm/vo/YzxhVO.java <==
package com.ejianc.business.sealm.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 印章销毁
 * 
 * @author generator
 * 
 */
public class YzxhVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private java.lang.String billCode; // 单据编码
    private String yzbhCode; // 印章登记编号
    private Long yzlbId; // 印章类别id
    private String yzlbName; // 印章类别名称
    private Long yzjbId; // 印章级别id
    private String yzjbName; // 印章级别名称
    private Long yylxId; // 用印类型id
    private String yylxName; // 用印类型名称
    private String kzzy; // 刻章字样
    private Long ssdwId; // 所属单位id
    private String ssdwName; // 所属单位名称
    private Long dqbgrId; // 当前保管人id
    private String dqbgrName; // 当前保管人名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date kzsjTime; // 刻制时间
    private Integer baqk; // 备案情况（默认0已备案）,0已备案，1未备案
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date basjTime; // 备案时间
    private Long badwId; // 备案单位id
    private String badwName; // 备案单位名称
    private Long scdwId; // 生产单位id
    private String scdwName; // 生产单位名称
    private Long xhzrrId; // 销毁责任人id
    private String xhzrrName; // 销毁责任人名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date xhDate; // 销毁日期
    private String remark; // 备注
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private java.util.Date beginDate; // 开始日期
    private java.util.Date endDate; // 结束日期
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private String updateUserName; // 修改人


    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 印章登记编号
     */
    public String getYzbhCode() {
        return yzbhCode;
    }

    /**
     * 印章登记编号
     */
    public void setYzbhCode(String yzbhCode) {
        this.yzbhCode = yzbhCode;
    }
    /**
     * 印章类别id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYzlbId() {
        return yzlbId;
    }

    /**
     * 印章类别id
     */
    @ReferDeserialTransfer
    public void setYzlbId(Long yzlbId) {
        this.yzlbId = yzlbId;
    }
    /**
     * 印章类别名称
     */
    public String getYzlbName() {
        return yzlbName;
    }

    /**
     * 印章类别名称
     */
    public void setYzlbName(String yzlbName) {
        this.yzlbName = yzlbName;
    }
    /**
     * 印章级别id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYzjbId() {
        return yzjbId;
    }

    /**
     * 印章级别id
     */
    @ReferDeserialTransfer
    public void setYzjbId(Long yzjbId) {
        this.yzjbId = yzjbId;
    }
    /**
     * 印章级别名称
     */
    public String getYzjbName() {
        return yzjbName;
    }

    /**
     * 印章级别名称
     */
    public void setYzjbName(String yzjbName) {
        this.yzjbName = yzjbName;
    }
    /**
     * 用印类型id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYylxId() {
        return yylxId;
    }

    /**
     * 用印类型id
     */
    @ReferDeserialTransfer
    public void setYylxId(Long yylxId) {
        this.yylxId = yylxId;
    }
    /**
     * 用印类型名称
     */
    public String getYylxName() {
        return yylxName;
    }

    /**
     * 用印类型名称
     */
    public void setYylxName(String yylxName) {
        this.yylxName = yylxName;
    }
    /**
     * 刻章字样
     */
    public String getKzzy() {
        return kzzy;
    }

    /**
     * 刻章字样
     */
    public void setKzzy(String kzzy) {
        this.kzzy = kzzy;
    }
    /**
     * 所属单位id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getSsdwId() {
        return ssdwId;
    }

    /**
     * 所属单位id
     */
    @ReferDeserialTransfer
    public void setSsdwId(Long ssdwId) {
        this.ssdwId = ssdwId;
    }
    /**
     * 所属单位名称
     */
    public String getSsdwName() {
        return ssdwName;
    }

    /**
     * 所属单位名称
     */
    public void setSsdwName(String ssdwName) {
        this.ssdwName = ssdwName;
    }
    /**
     * 当前保管人id
     */
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getDqbgrId() {
        return dqbgrId;
    }

    /**
     * 当前保管人id
     */
    @ReferDeserialTransfer
    public void setDqbgrId(Long dqbgrId) {
        this.dqbgrId = dqbgrId;
    }
    /**
     * 当前保管人名称
     */
    public String getDqbgrName() {
        return dqbgrName;
    }

    /**
     * 当前保管人名称
     */
    public void setDqbgrName(String dqbgrName) {
        this.dqbgrName = dqbgrName;
    }
    /**
     * 刻制时间
     */
    public java.util.Date getKzsjTime() {
        return kzsjTime;
    }

    /**
     * 刻制时间
     */
    public void setKzsjTime(java.util.Date kzsjTime) {
        this.kzsjTime = kzsjTime;
    }
    /**
     * 备案情况（默认0已备案）,0已备案，1未备案
     */
    public Integer getBaqk() {
        return baqk;
    }

    /**
     * 备案情况（默认0已备案）,0已备案，1未备案
     */
    public void setBaqk(Integer baqk) {
        this.baqk = baqk;
    }
    /**
     * 备案时间
     */
    public java.util.Date getBasjTime() {
        return basjTime;
    }

    /**
     * 备案时间
     */
    public void setBasjTime(java.util.Date basjTime) {
        this.basjTime = basjTime;
    }
    /**
     * 备案单位id
     */
    public Long getBadwId() {
        return badwId;
    }

    /**
     * 备案单位id
     */
    public void setBadwId(Long badwId) {
        this.badwId = badwId;
    }
    /**
     * 备案单位名称
     */
    public String getBadwName() {
        return badwName;
    }

    /**
     * 备案单位名称
     */
    public void setBadwName(String badwName) {
        this.badwName = badwName;
    }
    /**
     * 生产单位id
     */
    public Long getScdwId() {
        return scdwId;
    }

    /**
     * 生产单位id
     */
    public void setScdwId(Long scdwId) {
        this.scdwId = scdwId;
    }
    /**
     * 生产单位名称
     */
    public String getScdwName() {
        return scdwName;
    }

    /**
     * 生产单位名称
     */
    public void setScdwName(String scdwName) {
        this.scdwName = scdwName;
    }
    /**
     * 销毁责任人id
     */
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getXhzrrId() {
        return xhzrrId;
    }

    /**
     * 销毁责任人id
     */
    @ReferDeserialTransfer
    public void setXhzrrId(Long xhzrrId) {
        this.xhzrrId = xhzrrId;
    }
    /**
     * 销毁责任人名称
     */
    public String getXhzrrName() {
        return xhzrrName;
    }

    /**
     * 销毁责任人名称
     */
    public void setXhzrrName(String xhzrrName) {
        this.xhzrrName = xhzrrName;
    }
    /**
     * 销毁日期
     */
    public java.util.Date getXhDate() {
        return xhDate;
    }

    /**
     * 销毁日期
     */
    public void setXhDate(java.util.Date xhDate) {
        this.xhDate = xhDate;
    }
    /**
     * 备注
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 组织id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 开始日期
     */
    public java.util.Date getBeginDate() {
        return beginDate;
    }

    /**
     * 开始日期
     */
    public void setBeginDate(java.util.Date beginDate) {
        this.beginDate = beginDate;
    }
    /**
     * 结束日期
     */
    public java.util.Date getEndDate() {
        return endDate;
    }

    /**
     * 结束日期
     */
    public void setEndDate(java.util.Date endDate) {
        this.endDate = endDate;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 编制人
     */
    public String getCreateUserName() {
        return createUserName;
    }

    /**
     * 编制人
     */
    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 修改人
     */
    public String getUpdateUserName() {
        return updateUserName;
    }

    /**
     * 修改人
     */
    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    
}

==> ejc-sealm-api-3.0.0-20220822.102301-118-sources.jar: com.ejianc.business.sealm/vo/YzxhVO.java <==
package com.ejianc.business.sealm.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 印章销毁
 * 
 * @author generator
 * 
 */
public class YzxhVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private java.lang.String billCode; // 单据编码
    private String yzbhCode; // 印章登记编号
    private Long yzlbId; // 印章类别id
    private String yzlbName; // 印章类别名称
    private Long yzjbId; // 印章级别id
    private String yzjbName; // 印章级别名称
    private Long yylxId; // 用印类型id
    private String yylxName; // 用印类型名称
    private String kzzy; // 刻章字样
    private Long ssdwId; // 所属单位id
    private String ssdwName; // 所属单位名称
    private Long dqbgrId; // 当前保管人id
    private String dqbgrName; // 当前保管人名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date kzsjTime; // 刻制时间
    private Integer baqk; // 备案情况（默认0已备案）,0已备案，1未备案
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date basjTime; // 备案时间
    private Long badwId; // 备案单位id
    private String badwName; // 备案单位名称
    private Long scdwId; // 生产单位id
    private String scdwName; // 生产单位名称
    private Long xhzrrId; // 销毁责任人id
    private String xhzrrName; // 销毁责任人名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date xhDate; // 销毁日期
    private String remark; // 备注
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private java.util.Date beginDate; // 开始日期
    private java.util.Date endDate; // 结束日期
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private String updateUserName; // 修改人
    private String xhyy; // 销毁原因


    /**
     * 单据编码
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 印章登记编号
     */
    public String getYzbhCode() {
        return yzbhCode;
    }

    /**
     * 印章登记编号
     */
    public void setYzbhCode(String yzbhCode) {
        this.yzbhCode = yzbhCode;
    }
    /**
     * 印章类别id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYzlbId() {
        return yzlbId;
    }

    /**
     * 印章类别id
     */
    @ReferDeserialTransfer
    public void setYzlbId(Long yzlbId) {
        this.yzlbId = yzlbId;
    }
    /**
     * 印章类别名称
     */
    public String getYzlbName() {
        return yzlbName;
    }

    /**
     * 印章类别名称
     */
    public void setYzlbName(String yzlbName) {
        this.yzlbName = yzlbName;
    }
    /**
     * 印章级别id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYzjbId() {
        return yzjbId;
    }

    /**
     * 印章级别id
     */
    @ReferDeserialTransfer
    public void setYzjbId(Long yzjbId) {
        this.yzjbId = yzjbId;
    }
    /**
     * 印章级别名称
     */
    public String getYzjbName() {
        return yzjbName;
    }

    /**
     * 印章级别名称
     */
    public void setYzjbName(String yzjbName) {
        this.yzjbName = yzjbName;
    }
    /**
     * 用印类型id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYylxId() {
        return yylxId;
    }

    /**
     * 用印类型id
     */
    @ReferDeserialTransfer
    public void setYylxId(Long yylxId) {
        this.yylxId = yylxId;
    }
    /**
     * 用印类型名称
     */
    public String getYylxName() {
        return yylxName;
    }

    /**
     * 用印类型名称
     */
    public void setYylxName(String yylxName) {
        this.yylxName = yylxName;
    }
    /**
     * 刻章字样
     */
    public String getKzzy() {
        return kzzy;
    }

    /**
     * 刻章字样
     */
    public void setKzzy(String kzzy) {
        this.kzzy = kzzy;
    }
    /**
     * 所属单位id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getSsdwId() {
        return ssdwId;
    }

    /**
     * 所属单位id
     */
    @ReferDeserialTransfer
    public void setSsdwId(Long ssdwId) {
        this.ssdwId = ssdwId;
    }
    /**
     * 所属单位名称
     */
    public String getSsdwName() {
        return ssdwName;
    }

    /**
     * 所属单位名称
     */
    public void setSsdwName(String ssdwName) {
        this.ssdwName = ssdwName;
    }
    /**
     * 当前保管人id
     */
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getDqbgrId() {
        return dqbgrId;
    }

    /**
     * 当前保管人id
     */
    @ReferDeserialTransfer
    public void setDqbgrId(Long dqbgrId) {
        this.dqbgrId = dqbgrId;
    }
    /**
     * 当前保管人名称
     */
    public String getDqbgrName() {
        return dqbgrName;
    }

    /**
     * 当前保管人名称
     */
    public void setDqbgrName(String dqbgrName) {
        this.dqbgrName = dqbgrName;
    }
    /**
     * 刻制时间
     */
    public java.util.Date getKzsjTime() {
        return kzsjTime;
    }

    /**
     * 刻制时间
     */
    public void setKzsjTime(java.util.Date kzsjTime) {
        this.kzsjTime = kzsjTime;
    }
    /**
     * 备案情况（默认0已备案）,0已备案，1未备案
     */
    public Integer getBaqk() {
        return baqk;
    }

    /**
     * 备案情况（默认0已备案）,0已备案，1未备案
     */
    public void setBaqk(Integer baqk) {
        this.baqk = baqk;
    }
    /**
     * 备案时间
     */
    public java.util.Date getBasjTime() {
        return basjTime;
    }

    /**
     * 备案时间
     */
    public void setBasjTime(java.util.Date basjTime) {
        this.basjTime = basjTime;
    }
    /**
     * 备案单位id
     */
    public Long getBadwId() {
        return badwId;
    }

    /**
     * 备案单位id
     */
    public void setBadwId(Long badwId) {
        this.badwId = badwId;
    }
    /**
     * 备案单位名称
     */
    public String getBadwName() {
        return badwName;
    }

    /**
     * 备案单位名称
     */
    public void setBadwName(String badwName) {
        this.badwName = badwName;
    }
    /**
     * 生产单位id
     */
    public Long getScdwId() {
        return scdwId;
    }

    /**
     * 生产单位id
     */
    public void setScdwId(Long scdwId) {
        this.scdwId = scdwId;
    }
    /**
     * 生产单位名称
     */
    public String getScdwName() {
        return scdwName;
    }

    /**
     * 生产单位名称
     */
    public void setScdwName(String scdwName) {
        this.scdwName = scdwName;
    }
    /**
     * 销毁责任人id
     */
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getXhzrrId() {
        return xhzrrId;
    }

    /**
     * 销毁责任人id
     */
    @ReferDeserialTransfer
    public void setXhzrrId(Long xhzrrId) {
        this.xhzrrId = xhzrrId;
    }
    /**
     * 销毁责任人名称
     */
    public String getXhzrrName() {
        return xhzrrName;
    }

    /**
     * 销毁责任人名称
     */
    public void setXhzrrName(String xhzrrName) {
        this.xhzrrName = xhzrrName;
    }
    /**
     * 销毁日期
     */
    public java.util.Date getXhDate() {
        return xhDate;
    }

    /**
     * 销毁日期
     */
    public void setXhDate(java.util.Date xhDate) {
        this.xhDate = xhDate;
    }
    /**
     * 备注
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 组织id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 开始日期
     */
    public java.util.Date getBeginDate() {
        return beginDate;
    }

    /**
     * 开始日期
     */
    public void setBeginDate(java.util.Date beginDate) {
        this.beginDate = beginDate;
    }
    /**
     * 结束日期
     */
    public java.util.Date getEndDate() {
        return endDate;
    }

    /**
     * 结束日期
     */
    public void setEndDate(java.util.Date endDate) {
        this.endDate = endDate;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 编制人
     */
    public String getCreateUserName() {
        return createUserName;
    }

    /**
     * 编制人
     */
    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 修改人
     */
    public String getUpdateUserName() {
        return updateUserName;
    }

    /**
     * 修改人
     */
    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    /**
     * 销毁原因
     */
    public String getXhyy() {
        return xhyy;
    }

    /**
     * 销毁原因
     */
    public void setXhyy(String xhyy) {
        this.xhyy = xhyy;
    }
}
